@@ -481,6 +481,11 @@ domXPathNewCtxt(xmlNodePtr refNode) {
     return ctxt;
 }
 
+DLLEXPORT void
+domSetXPathCtxtErrorHandler(xmlXPathContextPtr ctxt, xmlStructuredErrorFunc error_func) {
+    ctxt->error = error_func;
+}
+
 DLLEXPORT void
 domXPathFreeCtxt(xmlXPathContextPtr ctxt) {
     if (ctxt->namespaces != NULL) {
